@@ -12,14 +12,18 @@ use warnings FATAL => 'all';
 package [% class_v %]::Root;
 use base 'HTML::Tested::ClassDBI';
 use [% root_class_v %]::DB::[% table_class_v %];
-__PACKAGE__->make_tested_hidden('ht_id', cdbi_bind => 'Primary');
-__PACKAGE__->make_tested_submit('submit_button', default_value => 'Submit');
-__PACKAGE__->make_tested_submit('delete_button', default_value => 'Delete');
-__PACKAGE__->make_tested_form(form => default_value => u => children => [[% FOREACH fields_v %]
-	[% field %] => edit_box => { cdbi_bind => '' },[% END %]
-]);
+use HTML::Tested qw(HTV);
+
+__PACKAGE__->ht_add_widget(HTV."::Hidden", 'ht_id', cdbi_bind => 'Primary');
+__PACKAGE__->ht_add_widget(HTV."::Submit", 'submit_button'
+			, default_value => 'Submit');
+__PACKAGE__->ht_add_widget(HTV."::Submit", 'delete_button'
+			, default_value => 'Delete');
+__PACKAGE__->ht_add_widget(HTV."::Form", form => default_value => 'u');
+[% FOREACH fields_v %]
+__PACKAGE__->ht_add_widget(HTV."::EditBox"
+			, [% field %] => cdbi_bind => '');[% END %]
 __PACKAGE__->bind_to_class_dbi('[% root_class_v %]::DB::[% table_class_v %]');
-__PACKAGE__->load_db_constraints;
 
 package [% class_v %];
 use base qw(Apache::SWIT::HTPage);
