@@ -14,16 +14,18 @@ use base 'HTML::Tested::ClassDBI';
 
 package [% class_v %];
 use base qw(Apache::SWIT::HTPage);
+use HTML::Tested qw(HTV);
 
 sub ht_root_class { return __PACKAGE__ . '::Root'; }
 
 sub on_inheritance_end {
 	my $class = shift;
 	my $rc = $class->ht_root_class;
-	$rc->make_tested_form(form => default_value => u => children => [[% FOREACH fields_v %]
-	[% field %] => marked_value => { cdbi_bind => '' },[% END %]
-]);
-	$rc->make_tested_link('edit_link'
+	[% FOREACH fields_v %]
+	$rc->ht_add_widget(HTV."::Marked"
+			, [% field %] => cdbi_bind => '');[% END %]
+	$rc->ht_add_widget(HTV."::Form", form => default_value => 'u');
+	$rc->ht_add_widget(HTV."::Link", 'edit_link'
 		, href_format => '../form/r?ht_id=%s'
 		, caption => 'Edit', cdbi_bind => [ 'Primary' ]);
 	$rc->bind_to_class_dbi($class->main_subsystem_class
